@@ -4,7 +4,7 @@ use warnings;
 
 use Importer;
 
-our $VERSION = '0.000058';
+our $VERSION = '0.000060';
 
 use Carp qw/croak/;
 
@@ -28,10 +28,10 @@ use Test2::Tools::Basic qw{
 use Test2::Tools::Compare qw{
     is like isnt unlike
     match mismatch validator
-    hash array bag object meta meta_check number string subset
+    hash array bag object meta meta_check number string subset bool
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
-    end filter_items
+    etc end filter_items
     T F D DF E DNE FDNE U
     event fail_events
     exact_ref
@@ -52,7 +52,7 @@ use Test2::Tools::Encoding  qw/set_encoding/;
 use Test2::Tools::Exports   qw/imported_ok not_imported_ok/;
 use Test2::Tools::Ref       qw/ref_ok ref_is ref_is_not/;
 use Test2::Tools::Mock      qw/mock mocked/;
-use Test2::Tools::Exception qw/dies lives/;
+use Test2::Tools::Exception qw/try_ok dies lives/;
 
 our @EXPORT = qw{
     ok pass fail diag note todo skip
@@ -74,14 +74,14 @@ our @EXPORT = qw{
     imported_ok not_imported_ok
     ref_ok ref_is ref_is_not
     mock mocked
-    dies lives
+    dies lives try_ok
 
     is like isnt unlike
     match mismatch validator
-    hash array bag object meta meta_check number string subset
+    hash array bag object meta meta_check number string subset bool
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
-    end filter_items
+    etc end filter_items
     T F D DF E DNE FDNE U
     event fail_events
     exact_ref
@@ -415,8 +415,6 @@ See L<Test2::Tools::Compare>.
 
 =item $check = check($thing)
 
-=item $check = end()
-
 =item $check = T()
 
 =item $check = F()
@@ -431,6 +429,10 @@ See L<Test2::Tools::Compare>.
 
 =item $check = exact_ref($ref)
 
+=item end()
+
+=item etc()
+
 =item filter_items { grep { ... } @_ }
 
 =item $check = event $type => ...
@@ -533,6 +535,8 @@ See L<Test2::Tools::Exception>.
 
 =item $bool = lives { ... }
 
+=item $bool = try_ok { ... }
+
 =back
 
 =head2 WARNINGS
