@@ -2,9 +2,10 @@ package Test2::Compare::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.000058';
+our $VERSION = '0.000060';
 
-use Carp qw/confess/;
+use Carp qw/confess croak/;
+use Scalar::Util qw/blessed/;
 
 use Test2::Util::Sub qw/sub_info/;
 use Test2::Compare::Delta();
@@ -19,6 +20,14 @@ use Test2::Util::HashBase qw{builder _file _lines _info called};
     *set_file  = \&set__file;
 }
 
+sub clone {
+    my $self = shift;
+    my $class = blessed($self);
+
+    # Shallow copy is good enough for all the current compare types.
+    return bless({%$self}, $class);
+}
+
 sub init {
     my $self = shift;
     $self->{_lines} = delete $self->{lines} if exists $self->{lines};
