@@ -2,9 +2,9 @@ package Test2::Compare::Delta;
 use strict;
 use warnings;
 
-our $VERSION = '0.000058';
+our $VERSION = '0.000060';
 
-use Test2::Util::HashBase qw{verified id got chk children dne exception};
+use Test2::Util::HashBase qw{verified id got chk children dne exception note};
 
 use Test2::Util::Table();
 use Test2::API qw/context/;
