@@ -4,9 +4,12 @@ use warnings;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000058';
+our $VERSION = '0.000060';
 
-use Test2::Util::HashBase qw/pattern negate stringify_got/;
+use Test2::Util::HashBase qw/pattern stringify_got/;
+
+# Overloads '!' for us.
+use Test2::Compare::Negatable;
 
 use Carp qw/croak/;
 
